==> startbootstrap-shop-homepage-4.2.2.tgz: package/README.md <==
# [Start Bootstrap - Shop Homepage](https://startbootstrap.com/templates/shop-homepage/)

[Shop Homepage](https://startbootstrap.com/templates/shop-homepage/) is a basic HTML online store homepage template for [Bootstrap](https://getbootstrap.com/) created by [Start Bootstrap](https://startbootstrap.com/).

## Preview

[![Shop Homepage Preview](https://startbootstrap.com/assets/img/screenshots/templates/shop-homepage.png)](https://startbootstrap.github.io/startbootstrap-shop-homepage/)

**[View Live Preview](https://startbootstrap.github.io/startbootstrap-shop-homepage/)**

## Status

[![GitHub license](https://img.shields.io/badge/license-MIT-blue.svg)](https://raw.githubusercontent.com/StartBootstrap/startbootstrap-shop-homepage/master/LICENSE)
[![npm version](https://img.shields.io/npm/v/startbootstrap-shop-homepage.svg)](https://www.npmjs.com/package/startbootstrap-shop-homepage)
[![Build Status](https://travis-ci.org/StartBootstrap/startbootstrap-shop-homepage.svg?branch=master)](https://travis-ci.org/StartBootstrap/startbootstrap-shop-homepage)
[![dependencies Status](https://david-dm.org/StartBootstrap/startbootstrap-shop-homepage/status.svg)](https://david-dm.org/StartBootstrap/startbootstrap-shop-homepage)
[![devDependencies Status](https://david-dm.org/StartBootstrap/startbootstrap-shop-homepage/dev-status.svg)](https://david-dm.org/StartBootstrap/startbootstrap-shop-homepage?type=dev)

## Download and Installation

To begin using this template, choose one of the following options to get started:

* [Download the latest release on Start Bootstrap](https://startbootstrap.com/templates/shop-homepage/)
* Install via npm: `npm i startbootstrap-shop-homepage`
* Clone the repo: `git clone https://github.com/StartBootstrap/startbootstrap-shop-homepage.git`
* [Fork, Clone, or Download on GitHub](https://github.com/StartBootstrap/startbootstrap-shop-homepage)

## Usage

### Basic Usage

After downloading, simply edit the HTML and CSS files included with the template in your favorite text editor to make changes. These are the only files you need to worry about, you can ignore everything else! To preview the changes you make to the code, you can open the `index.html` file in your web browser.

### Advanced Usage

After installation, run `npm install` and then run `npm start` which will open up a preview of the template in your default browser, watch for changes to core template files, and live reload the browser when changes are saved. You can view the `gulpfile.js` to see which tasks are included with the dev environment.

You must have npm and Gulp installed globally on your machine in order to use these features.

## Bugs and Issues

Have a bug or an issue with this template? [Open a new issue](https://github.com/StartBootstrap/startbootstrap-shop-homepage/issues) here on GitHub or leave a comment on the [template overview page at Start Bootstrap](https://startbootstrap.com/templates/shop-homepage/).

## About

Start Bootstrap is an open source library of free Bootstrap templates and themes. All of the free templates and themes on Start Bootstrap are released under the MIT license, which means you can use them for any purpose, even for commercial projects.

* <https://startbootstrap.com>
* <https://twitter.com/SBootstrap>

Start Bootstrap was created by and is maintained by **[David Miller](http://davidmiller.io/)**.

* <http://davidmiller.io>
* <https://twitter.com/davidmillerskt>
* <https://github.com/davidtmiller>

Start Bootstrap is based on the [Bootstrap](https://getbootstrap.com/) framework created by [Mark Otto](https://twitter.com/mdo) and [Jacob Thorton](https://twitter.com/fat).

## Copyright and License

Copyright 2013-2020 Start Bootstrap LLC. Code released under the [MIT](https://github.com/StartBootstrap/startbootstrap-shop-homepage/blob/gh-pages/LICENSE) license.

==> startbootstrap-shop-homepage-4.2.3.tgz: package/README.md <==
# [Start Bootstrap - Shop Homepage](https://startbootstrap.com/template/shop-homepage/)

[Shop Homepage](https://startbootstrap.com/template/shop-homepage/) is a basic HTML online store homepage template for [Bootstrap](https://getbootstrap.com/) created by [Start Bootstrap](https://startbootstrap.com/).

## Preview

[![Shop Homepage Preview](https://assets.startbootstrap.com/img/screenshots/templates/shop-homepage.png)](https://startbootstrap.github.io/startbootstrap-shop-homepage/)

**[View Live Preview](https://startbootstrap.github.io/startbootstrap-shop-homepage/)**

## Status

[![GitHub license](https://img.shields.io/badge/license-MIT-blue.svg)](https://raw.githubusercontent.com/StartBootstrap/startbootstrap-shop-homepage/master/LICENSE)
[![npm version](https://img.shields.io/npm/v/startbootstrap-shop-homepage.svg)](https://www.npmjs.com/package/startbootstrap-shop-homepage)
[![Build Status](https://travis-ci.org/StartBootstrap/startbootstrap-shop-homepage.svg?branch=master)](https://travis-ci.org/StartBootstrap/startbootstrap-shop-homepage)
[![dependencies Status](https://david-dm.org/StartBootstrap/startbootstrap-shop-homepage/status.svg)](https://david-dm.org/StartBootstrap/startbootstrap-shop-homepage)
[![devDependencies Status](https://david-dm.org/StartBootstrap/startbootstrap-shop-homepage/dev-status.svg)](https://david-dm.org/StartBootstrap/startbootstrap-shop-homepage?type=dev)

## Download and Installation

To begin using this template, choose one of the following options to get started:

* [Download the latest release on Start Bootstrap](https://startbootstrap.com/template/shop-homepage/)
* Install via npm: `npm i startbootstrap-shop-homepage`
* Clone the repo: `git clone https://github.com/StartBootstrap/startbootstrap-shop-homepage.git`
* [Fork, Clone, or Download on GitHub](https://github.com/StartBootstrap/startbootstrap-shop-homepage)

## Usage

### Basic Usage

After downloading, simply edit the HTML and CSS files included with the template in your favorite text editor to make changes. These are the only files you need to worry about, you can ignore everything else! To preview the changes you make to the code, you can open the `index.html` file in your web browser.

### Advanced Usage

After installation, run `npm install` and then run `npm start` which will open up a preview of the template in your default browser, watch for changes to core template files, and live reload the browser when changes are saved. You can view the `gulpfile.js` to see which tasks are included with the dev environment.

You must have npm and Gulp installed globally on your machine in order to use these features.

## Bugs and Issues

Have a bug or an issue with this template? [Open a new issue](https://github.com/StartBootstrap/startbootstrap-shop-homepage/issues) here on GitHub or leave a comment on the [template overview page at Start Bootstrap](https://startbootstrap.com/template/shop-homepage/).

## About

Start Bootstrap is an open source library of free Bootstrap templates and themes. All of the free templates and themes on Start Bootstrap are released under the MIT license, which means you can use them for any purpose, even for commercial projects.

* <https://startbootstrap.com>
* <https://twitter.com/SBootstrap>

Start Bootstrap was created by and is maintained by **[David Miller](https://davidmiller.io/)**.

* <https://davidmiller.io>
* <https://twitter.com/davidmillerhere>
* <https://github.com/davidtmiller>

Start Bootstrap is based on the [Bootstrap](https://getbootstrap.com/) framework created by [Mark Otto](https://twitter.com/mdo) and [Jacob Thorton](https://twitter.com/fat).

## Copyright and License

Copyright 2013-2020 Start Bootstrap LLC. Code released under the [MIT](https://github.com/StartBootstrap/startbootstrap-shop-homepage/blob/gh-pages/LICENSE) license.
